==> custom_pages-v1.12.8.zip: custom_pages/messages/pt/model.php <==
<?php

return [
    'Abstract' => 'Resumo',
    'Activate PHP based Pages and Snippets' => 'Activar Excertos e Páginas baseadas em PHP',
    'Attach Files' => 'Anexar Ficheiros',
    'Content' => 'Conteúdo',
    'Empty <br />Container' => '<em>Container</em> vazio',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Se desactivado, páginas PHP existentes permanecerão <em>online</em>, mas não poderão ser criadas.',
    'Label' => 'Etiqueta',
    'Open in new window' => 'Abrir em nova janela',
    'PHP view path for custom space pages' => 'Destino da vista PHP para páginas personalizáveis do espaço',
    'PHP view path for custom space snippets' => 'Destino da vista PHP para trechos personalizáveis do espaço',
    'PHP view path for global custom pages' => 'Destino da vista PHP para páginas personalizáveis globais',
    'PHP view path for global custom snippets' => 'Destino da vista PHP para trechos personalizáveis globais',
    'Placeholder name' => 'Nome do <em>placeholder</em>',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'O nome do elemento tem de conter pelo menos dois caracteres sem espaços ou símbolos especiais excepto \'_\'',
    'The given element name is already in use for this template.' => 'O elemento dado já está em uso neste modelo.',
    'The given view file path does not exist.' => 'O destino de vista de ficheiro dado não existe.',
    'Url shortcut' => 'Atalho URL',
    'View' => 'Ver',
    'Visibility' => 'Visibilidade',
    'page' => 'página',
    'snippet' => 'excerto',
    'Editors' => '',
    'Language-Based Visibility' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'Visible to Group Members' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/pt/model.php <==
<?php

return [
    'Abstract' => 'Resumo',
    'Activate PHP based Pages and Snippets' => 'Activar Excertos e Páginas baseadas em PHP',
    'Attach Files' => 'Anexar Ficheiros',
    'Content' => 'Conteúdo',
    'Empty <br />Container' => '<em>Container</em> vazio',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Se desactivado, páginas PHP existentes permanecerão <em>online</em>, mas não poderão ser criadas.',
    'Label' => 'Etiqueta',
    'Open in new window' => 'Abrir em nova janela',
    'PHP view path for custom space pages' => 'Destino da vista PHP para páginas personalizáveis do espaço',
    'PHP view path for custom space snippets' => 'Destino da vista PHP para trechos personalizáveis do espaço',
    'PHP view path for global custom pages' => 'Destino da vista PHP para páginas personalizáveis globais',
    'PHP view path for global custom snippets' => 'Destino da vista PHP para trechos personalizáveis globais',
    'Placeholder name' => 'Nome do <em>placeholder</em>',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'O nome do elemento tem de conter pelo menos dois caracteres sem espaços ou símbolos especiais excepto \'_\'',
    'The given element name is already in use for this template.' => 'O elemento dado já está em uso neste modelo.',
    'The given view file path does not exist.' => 'O destino de vista de ficheiro dado não existe.',
    'Url shortcut' => 'Atalho URL',
    'View' => 'Ver',
    'Visibility' => 'Visibilidade',
    'page' => 'página',
    'snippet' => 'excerto',
    'Editors' => '',
    'Hide in Navigation' => '',
    'Language-Based Visibility' => '',
    'Mobile App Users' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'The element name is reserved, please choose another one.' => '',
    'Visible to Group Members' => '',
];
